pub struct LeanModuleDescriptor {
pub module: String,
pub path: PathBuf,
pub source_root: String,
}Expand description
A discovered Lean source module in a Lake project.
Fields
module: Stringpath: PathBufsource_root: StringTrait Implementations
Sourceimpl Clone for LeanModuleDescriptor
impl Clone for LeanModuleDescriptor
Sourcefn clone(&self) -> LeanModuleDescriptor
fn clone(&self) -> LeanModuleDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LeanModuleDescriptor
impl Debug for LeanModuleDescriptor
Sourceimpl PartialEq for LeanModuleDescriptor
impl PartialEq for LeanModuleDescriptor
Sourcefn eq(&self, other: &LeanModuleDescriptor) -> bool
fn eq(&self, other: &LeanModuleDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for LeanModuleDescriptor
impl StructuralPartialEq for LeanModuleDescriptor