pub struct LeanModuleDiscoveryOptions { /* private fields */ }Expand description
Options for Lake module discovery.
Implementations
Sourceimpl LeanModuleDiscoveryOptions
impl LeanModuleDiscoveryOptions
Sourcepub fn new(requested_root: impl Into<PathBuf>) -> Self
pub fn new(requested_root: impl Into<PathBuf>) -> Self
Discover modules for the Lake project at or below requested_root.
Sourcepub fn selected_roots(
self,
roots: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn selected_roots( self, roots: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Restrict discovery to these Lake module roots.
Sourcepub fn toolchain(self, toolchain: ToolchainFingerprint) -> Self
pub fn toolchain(self, toolchain: ToolchainFingerprint) -> Self
Override the toolchain fingerprint used for validation and fingerprints.
This is primarily useful for tests and external planners that compare a separately obtained toolchain identity.