BuiltLeanCapability

Struct BuiltLeanCapability 

pub struct BuiltLeanCapability { /* private fields */ }
Metadata produced by CargoLeanCapability.

Implementations

Source

impl BuiltLeanCapability

pub fn dylib_path(&self) -> &Path

Built shared-library path.

pub fn env_var(&self) -> &str

Cargo environment variable that stores the built dylib path.

pub fn manifest_path(&self) -> &Path

JSON artifact manifest path emitted by the build helper.

pub fn manifest_env_var(&self) -> &str

Cargo environment variable that stores the artifact manifest path.

pub fn package(&self) -> &str

Lake package name.

pub fn module(&self) -> &str

Root Lean module initialized by Rust.

pub fn target_name(&self) -> &str

Lake target name.

pub fn project_root(&self) -> &Path

Canonical Lake project root.