pub struct BuiltLeanCapability { /* private fields */ }Expand description
Metadata produced by CargoLeanCapability.
Implementations
Sourceimpl BuiltLeanCapability
impl BuiltLeanCapability
Sourcepub fn dylib_path(&self) -> &Path
pub fn dylib_path(&self) -> &Path
Built shared-library path.
Sourcepub fn manifest_path(&self) -> &Path
pub fn manifest_path(&self) -> &Path
JSON artifact manifest path emitted by the build helper.
Sourcepub fn manifest_env_var(&self) -> &str
pub fn manifest_env_var(&self) -> &str
Cargo environment variable that stores the artifact manifest path.
Sourcepub fn target_name(&self) -> &str
pub fn target_name(&self) -> &str
Lake target name.
Sourcepub fn project_root(&self) -> &Path
pub fn project_root(&self) -> &Path
Canonical Lake project root.